==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/ru/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Информация</strong>',
  '<strong>Profile</strong> Permissions' => 'Разрешения <strong>Профиля</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Настройки и конфигурация</strong>',
  '<strong>User</strong> administration' => '<strong>Управление пользователями</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Предупреждение:</strong> Все индивидуальные настройки прав доступа к профилю сбрасываются на значения по умолчанию!',
  'Accept user: <strong>{displayName}</strong> ' => 'Активировать пользователя: <strong>{displayName}</strong>',
  'Account' => 'Аккаунт',
  'Account Request for \'{displayName}\' has been approved.' => 'Учётная запись для \'{displayName}\' была утверждена.',
  'Account Request for \'{displayName}\' has been declined.' => 'Учётная запись для \'{displayName}\' была отклонена.',
  'Actions' => 'Действия',
  'Active users' => 'Активные пользователи',
  'Add Groups...' => 'Добавить Группы...',
  'Add a separate page for the group to the directory.' => 'Добавьте отдельную страницу для группы в каталог.',
  'Add new category' => 'Добавить новую категорию',
  'Add new field' => 'Добавить новое поле',
  'Add new group' => 'Создать новую группу',
  'Add new members...' => 'Добавить участников...',
  'Add new user' => 'Добавить нового пользователя',
  'Administrator group could not be deleted!' => 'Группа администратора не может быть удалена!',
  'All open registration invitations were successfully deleted.' => 'Все открытые приглашения на регистрацию были успешно удалены.',
  'All the personal data of this user will be irrevocably deleted.' => 'Все личные данные этого пользователя будут безвозвратно удалены.',
  'Allow' => 'Разрешить',
  'Allow users to set individual permissions for their own profile?' => 'Разрешить пользователям устанавливать индивидуальные разрешения для своего профиля?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Разрешить ограниченный доступ для незарегистрированных пользователей (гостей)',
  'Applied to new or existing users without any other group membership.' => 'Применимо к новым или существующим пользователям без какого-либо другого членства в группе.',
  'Are you really sure that you want to disable this user?' => 'Вы действительно уверены, что хотите отключить этого пользователя?',
  'Are you really sure that you want to enable this user?' => 'Вы действительно уверены, что хотите подключить этого пользователя?',
  'Are you really sure that you want to impersonate this user?' => 'Вы действительно уверены, что хотите выдать себя за этого пользователя?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Ты действительно уверены? Пользователи, которые не назначены в другую группу, автоматически назначаются в группу по умолчанию.',
  'Are you sure that you want to delete following user?' => 'Вы уверены, что хотите удалить этого пользователя?',
  'Cancel' => 'Отменить',
  'Click here to review' => 'Нажмите здесь, чтобы просмотреть',
  'Confirm user deletion' => 'Подтвердите удаление пользователя',
  'Could not load category.' => 'Невозможно загрузить категорию.',
  'Create new group' => 'Создать новую группу',
  'Create new profile category' => 'Создать новую категорию профиля',
  'Create new profile field' => 'Добавить новое поле профиля',
  'Deactivate' => 'Деактивировать',
  'Deactivate individual profile permissions?' => 'Деактивировать разрешения индивидуального профиля?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Отклонить и удалить пользователя: <strong>{displayName}</strong>',
  'Default' => 'По умолчанию',
  'Default Profile Permissions' => 'Разрешения профиля по умолчанию',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Время бездействия пользователя до авто-выхода по умолчанию (в секундах, опционально)',
  'Default user profile visibility' => 'Кому виден профиль пользователя по умолчанию',
  'Delete' => 'Удалить',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => 'Выключить',
  'Disabled' => 'Отключён',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => 'Изменить категорию профиля',
  'Edit profile field' => 'Изменить поле профиля',
  'Edit user: {name}' => 'Редактировать пользователя: {name}',
  'Enable' => 'Включить',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Включён',
  'Group Manager' => 'Менеджер группы',
  'Group not found!' => 'Группа не найдена!',
  'Group user not found!' => 'Участник группы не найден!',
  'Groups' => 'Группы',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => 'Здесь вы можете создавать или редактировать категории и поля профилей пользователей.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'Last login' => 'Последний визит',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Управление группой: {groupName}',
  'Manage groups' => 'Управление группами',
  'Manage profile attributes' => 'Управление атрибутами профиля',
  'Member since' => '',
  'Members' => 'Участники',
  'Members can invite external users by email' => 'Участники могут приглашать новых пользователей по электронной почте',
  'Message' => 'Сообщение',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Минимальное значение - 20 секунд. Если не установлено - сессия завершится через 1400 секунд (24 минуты) независимо от активности (таймаут сессии по умолчанию)',
  'New approval requests' => 'Новые запросы на подтверждение',
  'New users can register' => 'Любой пользователь может зарегистрироваться',
  'No' => 'Нет',
  'No value found!' => 'Значение не найдено!',
  'One or more user needs your approval as group admin.' => 'Один или несколько пользователей нуждаются в вашем подтверждении в качестве администратора группы.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Применяется только в том случае, если включен ограниченный доступ для незарегистрированных пользователей. Влияет только на новых пользователей.',
  'Overview' => 'Список пользователей',
  'Password' => 'Пароль',
  'Pending approvals' => 'В ожидании подтверждения',
  'Pending user approvals' => 'Ожидает подтверждения пользователей',
  'Permanently delete' => '',
  'Permissions' => 'Доступ',
  'Profile Permissions' => '',
  'Profiles' => 'Профили',
  'Remove from group' => 'Удалить из группы',
  'Require group admin approval after registration' => 'После регистрации требуется одобрение администратора',
  'Resend invitation email' => '',
  'Save' => 'Сохранить',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Send & save' => 'Отправить и сохранить',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Отправить приглашеине',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Настройки',
  'Show group selection at registration' => '',
  'Subject' => 'Тема',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => 'Список содержит всех зарегистрированных пользователей, ожидающих подверждения.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ниже приведён список зарегистрированных пользователей  с возможностью для просмотра, редактирования и удаления пользователей.',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Не подтверждён',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Пользователь не найден!',
  'Users' => 'Пользователи',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Пользователи могут быть назначены в различные группы (например, команды, отделы и так далее), с определенными стандартными сообществами для той или иной группы, а также менеджерами групп и сопутствующими правами.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => 'Только зарегистрированным пользователям',
  'Visible for members+guests' => 'Зарегистрированным пользователям и гостям',
  'Yes' => 'Да',
  'You can only delete empty categories!' => 'Вы можете удалять только пустые категории!',
  'You cannot delete yourself!' => 'Вы не можете удалить себя!',
  'never' => 'никогда',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/ru/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Информация</strong>',
  '<strong>Profile</strong> Permissions' => 'Разрешения <strong>Профиля</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Настройки и конфигурация</strong>',
  '<strong>User</strong> administration' => '<strong>Управление пользователями</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Предупреждение:</strong> Все индивидуальные настройки прав доступа к профилю сбрасываются на значения по умолчанию!',
  'Accept user: <strong>{displayName}</strong> ' => 'Активировать пользователя: <strong>{displayName}</strong>',
  'Account' => 'Аккаунт',
  'Account Request for \'{displayName}\' has been approved.' => 'Учётная запись для \'{displayName}\' была утверждена.',
  'Account Request for \'{displayName}\' has been declined.' => 'Учётная запись для \'{displayName}\' была отклонена.',
  'Actions' => 'Действия',
  'Active users' => 'Активные пользователи',
  'Add Groups...' => 'Добавить Группы...',
  'Add new category' => 'Добавить новую категорию',
  'Add new field' => 'Добавить новое поле',
  'Add new group' => 'Создать новую группу',
  'Add new members...' => 'Добавить участников...',
  'Add new user' => 'Добавить нового пользователя',
  'Administrator group could not be deleted!' => 'Группа администратора не может быть удалена!',
  'All open registration invitations were successfully deleted.' => 'Все открытые приглашения на регистрацию были успешно удалены.',
  'All the personal data of this user will be irrevocably deleted.' => 'Все личные данные этого пользователя будут безвозвратно удалены.',
  'Allow' => 'Разрешить',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => 'Разрешить пользователям устанавливать индивидуальные разрешения для своего профиля?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Разрешить ограниченный доступ для незарегистрированных пользователей (гостей)',
  'Applied to new or existing users without any other group membership.' => 'Применимо к новым или существующим пользователям без какого-либо другого членства в группе.',
  'Are you really sure that you want to disable this user?' => 'Вы действительно уверены, что хотите отключить этого пользователя?',
  'Are you really sure that you want to enable this user?' => 'Вы действительно уверены, что хотите подключить этого пользователя?',
  'Are you really sure that you want to impersonate this user?' => 'Вы действительно уверены, что хотите выдать себя за этого пользователя?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Ты действительно уверены? Пользователи, которые не назначены в другую группу, автоматически назначаются в группу по умолчанию.',
  'Are you sure that you want to delete following user?' => 'Вы уверены, что хотите удалить этого пользователя?',
  'Cancel' => 'Отменить',
  'Click here to review' => 'Нажмите здесь, чтобы просмотреть',
  'Confirm user deletion' => 'Подтвердите удаление пользователя',
  'Could not load category.' => 'Невозможно загрузить категорию.',
  'Create new group' => 'Создать новую группу',
  'Create new profile category' => 'Создать новую категорию профиля',
  'Create new profile field' => 'Добавить новое поле профиля',
  'Deactivate' => 'Деактивировать',
  'Deactivate individual profile permissions?' => 'Деактивировать разрешения индивидуального профиля?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Отклонить и удалить пользователя: <strong>{displayName}</strong>',
  'Default' => 'По умолчанию',
  'Default Profile Permissions' => 'Разрешения профиля по умолчанию',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Время бездействия пользователя до авто-выхода по умолчанию (в секундах, опционально)',
  'Default user profile visibility' => 'Кому виден профиль пользователя по умолчанию',
  'Delete' => 'Удалить',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => 'Выключить',
  'Disabled' => 'Отключён',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => 'Изменить категорию профиля',
  'Edit profile field' => 'Изменить поле профиля',
  'Edit user: {name}' => 'Редактировать пользователя: {name}',
  'Enable' => 'Включить',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Включён',
  'First name' => 'Имя',
  'Group Manager' => 'Менеджер группы',
  'Group not found!' => 'Группа не найдена!',
  'Group user not found!' => 'Участник группы не найден!',
  'Groups' => 'Группы',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Здесь вы можете создавать или редактировать категории и поля профилей пользователей.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => '',
  'Last login' => 'Последний визит',
  'Last name' => 'Фамилия',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Управление группой: {groupName}',
  'Manage groups' => 'Управление группами',
  'Manage profile attributes' => 'Управление атрибутами профиля',
  'Member since' => '',
  'Members' => 'Участники',
  'Members can invite external users by email' => 'Участники могут приглашать новых пользователей по электронной почте',
  'Message' => 'Сообщение',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Минимальное значение - 20 секунд. Если не установлено - сессия завершится через 1400 секунд (24 минуты) независимо от активности (таймаут сессии по умолчанию)',
  'New approval requests' => 'Новые запросы на подтверждение',
  'New users can register' => 'Любой пользователь может зарегистрироваться',
  'No' => 'Нет',
  'No value found!' => 'Значение не найдено!',
  'None' => 'Ничего',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => 'Один или несколько пользователей нуждаются в вашем подтверждении в качестве администратора группы.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Применяется только в том случае, если включен ограниченный доступ для незарегистрированных пользователей. Влияет только на новых пользователей.',
  'Overview' => 'Список пользователей',
  'Password' => 'Пароль',
  'Pending approvals' => 'В ожидании подтверждения',
  'Pending user approvals' => 'Ожидает подтверждения пользователей',
  'People' => 'Люди',
  'Permanently delete' => '',
  'Permissions' => 'Доступ',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => 'Профили',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => 'Удалить из группы',
  'Require group admin approval after registration' => 'После регистрации требуется одобрение администратора',
  'Resend invitation email' => '',
  'Save' => 'Сохранить',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Отправить и отказать',
  'Send & save' => 'Отправить и сохранить',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Отправить приглашеине',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Настройки',
  'Show group selection at registration' => '',
  'Subject' => 'Тема',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => 'Список содержит всех зарегистрированных пользователей, ожидающих подверждения.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ниже приведён список зарегистрированных пользователей  с возможностью для просмотра, редактирования и удаления пользователей.',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Не подтверждён',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'Пользователь не найден!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Пользователи могут быть назначены в различные группы (например, команды, отделы и так далее), с определенными стандартными сообществами для той или иной группы, а также менеджерами групп и сопутствующими правами.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => 'Только зарегистрированным пользователям',
  'Visible for members+guests' => 'Зарегистрированным пользователям и гостям',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => 'Да',
  'You can only delete empty categories!' => 'Вы можете удалять только пустые категории!',
  'You cannot delete yourself!' => 'Вы не можете удалить себя!',
  'never' => 'никогда',
);
